<?php

namespace Drupal\sso_connector\Event;

use Drupal\user\UserInterface;
use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event that is dispatched when a user logs in.
 *
 * This event allows modules to react to user logins, providing access
 * to the user entity. It can be used to trigger additional processes
 * or logic necessary after a user successfully logs in.
 */
class UserLoginEvent extends Event {
  /**
   * The event name.
   */
  public const LOGIN = 'sso_connector.user.login';

  /**
   * The user entity.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $user;

  /**
   * Constructs a new UserLoginEvent.
   *
   * @param \Drupal\user\UserInterface $user
   *   The user entity.
   */
  public function __construct(UserInterface $user) {
    $this->user = $user;
  }

  /**
   * Gets the user entity.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity.
   */
  public function getUser(): UserInterface {
    return $this->user;
  }

}
